.. txreactorfixture documentation master file, created by
   sphinx-quickstart on Wed Nov  9 19:33:32 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Twisted integration with Python Testfixtures
============================================

txfixtures hooks into the testtools `test fixture`_ interface, so that you can
write tests that rely on having an external Twisted daemon.

See:

* https://launchpad.net/txfixtures
* https://launchpad.net/testtools

Contents:

.. toctree::
   :maxdepth: 1

   reactor
   service
   phantomjs
   api

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _`test fixture`: http://testtools.readthedocs.io/en/latest/for-test-authors.html#fixtures

